==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/ecrire/lang/public_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Accogliu di u situ', # MODIF
	'article' => 'Article', # NEW
	'articles' => 'Artìculi',
	'articles_auteur' => 'Artìculi di st\'autore',
	'articles_populaires' => 'Artìculi i più pupulari',
	'articles_rubrique' => 'Artìculi di sta rùbbrica',
	'aucun_article' => 'Ùn ci hè artìculu à st\'indirizzu',
	'aucun_auteur' => 'Ùn ci hè autore à st\'indirizzu',
	'aucun_site' => 'Ùn ci hè situ à st\'indirizzu',
	'aucune_breve' => 'Ùn ci hè dispacciu à st\'indirizzu',
	'aucune_rubrique' => 'Ùn ci hè rùbbrica à st\'indirizzu',
	'auteur' => 'Auteur', # NEW
	'autres' => 'Altri',
	'autres_breves' => 'Altri dispacci',
	'autres_groupes_mots_clefs' => 'Altri gruppi di segni',
	'autres_sites' => 'Alri siti',

	// B
	'bonjour' => 'Salute',

	// C
	'commenter_site' => 'Cummentà stu situ',
	'contact' => 'Contact', # NEW
	'copie_document_impossible' => 'Impussìbule di cupià u ducumentu',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ùltimu aghjuntu',
	'dernieres_breves' => 'Ùltimi dispacci',
	'derniers_articles' => 'Ùltimi artìculi',
	'derniers_commentaires' => 'Ùltimi cummenti',
	'derniers_messages_forum' => 'Ùltimi messagi pubblicati in i fori',

	// E
	'edition_mode_texte' => 'Edizione in modu testu di',
	'en_reponse' => 'Da risposta à :',
	'en_resume' => 'Da riassuntu',
	'envoyer_message' => 'Mandà u messagiu',
	'espace_prive' => 'Spaziu privatu',

	// F
	'formats_acceptes' => 'Furmati accettati : @formats@.',

	// H
	'hierarchie_site' => 'Ierarchia di u situ',

	// J
	'jours' => 'ghjorni',

	// L
	'lien_connecter' => 'Cunnette si',

	// M
	'meme_auteur' => 'Da listessu autore',
	'meme_rubrique' => 'In a listessa rùbbrica',
	'memes_auteurs' => 'Da listessi autori',
	'message' => 'Messagiu',
	'messages_forum' => 'Messagi di foru', # MODIF
	'messages_recents' => 'Messagi di fori i più recenti',
	'mots_clef' => 'Mot-clé', # NEW
	'mots_clefs' => 'Segni',
	'mots_clefs_meme_groupe' => 'Segni in u listessu gruppu',

	// N
	'navigation' => 'Navigazione',
	'nom' => 'Nome',
	'nouveautes' => 'E nuvità',
	'nouveautes_web' => 'Nuvità nant\'à u web',
	'nouveaux_articles' => 'Nuvelli artìculi',
	'nouvelles_breves' => 'Nuvelli dispacci',

	// P
	'page_precedente' => 'pàgina prima',
	'page_suivante' => 'pàgina dopu',
	'par_auteur' => 'da ',
	'participer_site' => 'Pudete puru participà à a vita di stu situ è prupone i vostri artìculi iscrivendu vi quì sottu. 
	Riceverete sùbbitu un email cù i vostri còdici d\'accessu à u spaziu privatu di u situ.',
	'plan_site' => 'Pianu di u situ',
	'popularite' => 'Pupularità',
	'poster_message' => 'Pustà un messagiu',
	'proposer_site' => 'Pudete puru prupone un situ da aghjunghje in sta rùbbrica :',

	// R
	'repondre_article' => 'Risponde à st\'artìculu',
	'repondre_breve' => 'Risponde à stu dispacciu',
	'resultats_recherche' => 'Risultati di a ricerca',
	'retour_debut_forums' => 'Ritornu à u principiu di i fori',
	'rubrique' => 'Rùbbrica',
	'rubriques' => 'Rùbbriche',

	// S
	'signatures_petition' => 'Zifre',
	'site_realise_avec_spip' => 'Situ fattu cù SPIP',
	'sites_web' => 'Siti Web',
	'sous_rubriques' => 'Sotturùbbriche',
	'spam' => 'Spam',
	'suite' => 'sèguita',
	'sur_web' => 'Nant\'à u Web',
	'syndiquer_rubrique' => 'Sindicà sta rùbbrica',
	'syndiquer_site' => 'Sindicà u situ sanu',

	// T
	'texte_lettre_information' => 'Eccu a lèttera d\'infurmazione di u situ',
	'texte_lettre_information_2' => 'Sta lèttera face u censu di l\'artìculi è i dispacci dipoi', # MODIF

	// V
	'ver_imprimer' => 'Versione da stampà',
	'voir_en_ligne' => 'Vede in ligna',
	'voir_squelette' => 'vede u mudellu di sta pàgina'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/ecrire/lang/public_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/public?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Accogliu di u situ', # MODIF
	'article' => 'Artìculu',
	'articles' => 'Artìculi',
	'articles_auteur' => 'Artìculi di st\'autore',
	'articles_populaires' => 'Artìculi i più pupulari',
	'articles_rubrique' => 'Artìculi di sta rùbbrica',
	'aucun_article' => 'Ùn ci hè artìculu à st\'indirizzu',
	'aucun_auteur' => 'Ùn ci hè autore à st\'indirizzu',
	'aucun_site' => 'Ùn ci hè situ à st\'indirizzu',
	'aucune_breve' => 'Ùn ci hè dispacciu à st\'indirizzu',
	'aucune_rubrique' => 'Ùn ci hè rùbbrica à st\'indirizzu',
	'auteur' => 'Autore',
	'autres' => 'Altri',
	'autres_breves' => 'Altri dispacci',
	'autres_groupes_mots_clefs' => 'Altri gruppi di segni',
	'autres_sites' => 'Alri siti',

	// B
	'bonjour' => 'Salute',

	// C
	'commenter_site' => 'Cummentà stu situ',
	'contact' => 'Cuntattu',
	'copie_document_impossible' => 'Impussìbule di cupià u ducumentu',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Ùltimu aghjuntu',
	'dernieres_breves' => 'Ùltimi dispacci',
	'derniers_articles' => 'Ùltimi artìculi',
	'derniers_commentaires' => 'Ùltimi cummenti',
	'derniers_messages_forum' => 'Ùltimi messagi pubblicati in i fori',

	// E
	'edition_mode_texte' => 'Edizione in modu testu di',
	'en_reponse' => 'Da risposta à :',
	'en_resume' => 'Da riassuntu',
	'envoyer_message' => 'Mandà u messagiu',
	'espace_prive' => 'Spaziu privatu',

	// F
	'formats_acceptes' => 'Furmati accettati : @formats@.',

	// H
	'hierarchie_site' => 'Ierarchia di u situ',

	// J
	'jours' => 'ghjorni',

	// L
	'lien_connecter' => 'Cunnette si',

	// M
	'meme_auteur' => 'Da listessu autore',
	'meme_rubrique' => 'In a listessa rùbbrica',
	'memes_auteurs' => 'Da listessi autori',
	'message' => 'Messagiu',
	'messages_forum' => 'Messagi di foru', # MODIF
	'messages_recents' => 'Messagi di fori i più recenti',
	'mots_clef' => 'Mot-clé', # NEW
	'mots_clefs' => 'Segni',
	'mots_clefs_meme_groupe' => 'Segni in u listessu gruppu',

	// N
	'navigation' => 'Navigazione',
	'nom' => 'Nome',
	'nouveautes' => 'E nuvità',
	'nouveautes_web' => 'Nuvità nant\'à u web',
	'nouveaux_articles' => 'Nuvelli artìculi',
	'nouvelles_breves' => 'Nuvelli dispacci',

	// P
	'page_precedente' => 'pàgina prima',
	'page_suivante' => 'pàgina dopu',
	'par_auteur' => 'da ',
	'participer_site' => 'Pudete puru participà à a vita di stu situ è prupone i vostri artìculi iscrivendu vi quì sottu. 
	Riceverete sùbbitu un email cù i vostri còdici d\'accessu à u spaziu privatu di u situ.',
	'plan_site' => 'Pianu di u situ',
	'popularite' => 'Pupularità',
	'poster_message' => 'Pustà un messagiu',
	'proposer_site' => 'Pudete puru prupone un situ da aghjunghje in sta rùbbrica :',

	// R
	'repondre_article' => 'Risponde à st\'artìculu',
	'repondre_breve' => 'Risponde à stu dispacciu',
	'resultats_recherche' => 'Risultati di a ricerca',
	'retour_debut_forums' => 'Ritornu à u principiu di i fori',
	'rubrique' => 'Rùbbrica',
	'rubriques' => 'Rùbbriche',

	// S
	'signatures_petition' => 'Zifre',
	'site_realise_avec_spip' => 'Situ fattu cù SPIP',
	'sites_web' => 'Siti Web',
	'sous_rubriques' => 'Sotturùbbriche',
	'spam' => 'Spam',
	'suite' => 'sèguita',
	'sur_web' => 'Nant\'à u Web',
	'syndiquer_rubrique' => 'Sindicà sta rùbbrica',
	'syndiquer_site' => 'Sindicà u situ sanu',

	// T
	'texte_lettre_information' => 'Eccu a lèttera d\'infurmazione di u situ',
	'texte_lettre_information_2' => 'Sta lèttera face u censu di l\'artìculi è i dispacci dipoi', # MODIF

	// V
	'ver_imprimer' => 'Versione da stampà',
	'voir_en_ligne' => 'Vede in ligna',
	'voir_squelette' => 'vede u mudellu di sta pàgina'
);

?>
